2026-04-08 Version: 1.5.2
- Update API CreateInstanceV1: add request parameters body.EnableMultiAz.
- Update API DescribeInstances: add response parameters Body.Data.$.EnableMultiAz.
- Update API ListOperationActivity: add response parameters Body.Data.$.ConsoleRetryCount.
- Update API ListOperationActivity: add response parameters Body.Data.$.ErrMessage.


2026-03-18 Version: 1.5.0
- Support API AddBackupPolicy.
- Support API CheckInventory.
- Support API CreateAgentResource.
- Support API CreateScalingRule.
- Support API DeleteBackup.
- Support API DeleteBackupPolicy.
- Support API DeleteInnerIpWhitelistGroup.
- Support API DeleteScalingRule.
- Support API DescribeAvailableZones.
- Support API DescribeBackupPolicies.
- Support API DescribeBackups.
- Support API DescribeEventNames.
- Support API DescribeInnerIpWhitelistGroups.
- Support API DescribeInstanceDiagnosisResult.
- Support API DescribeInstanceMetaToken.
- Support API DescribeRegions.
- Support API DescribeResourceConstraints.
- Support API DescribeSystemTimezone.
- Support API DescribeTimeTriggerScalingRules.
- Support API EnableInternalSlb.
- Support API EnableMultiAz.
- Support API GetNodeGroupFeatureGate.
- Support API ListOperationActivity.
- Support API ListOperationHistory.
- Support API ModifyHostAlias.
- Support API ModifyMaintainableTime.
- Support API ModifyScalingRule.
- Support API ModifySpecType.
- Support API ModifySpecTypePreCheck.
- Support API ModifyUserPassword.
- Support API QueryEnableMultiAzPrice.
- Support API QueryMinorVersion.
- Support API QueryModifyChargeTypePrice.
- Support API QueryModifyCuPrice.
- Support API QueryModifyDiskNumberPrice.
- Support API QueryModifyDiskPerformanceLevelPrice.
- Support API QueryModifyDiskSizePrice.
- Support API QueryModifyDiskTypePrice.
- Support API QueryModifyNodeNumberPrice.
- Support API QueryModifySpecTypePrice.
- Support API QueryPriceV1.
- Support API QueryRefundPrice.
- Support API QueryRenewPrice.
- Support API QueryUnpaidOrder.
- Support API RebootECS.
- Support API RenewInstance.
- Support API SwitchActiveStandbyZones.
- Support API ToggleAutoMinorVersionUpgrade.
- Support API UpdateBackup.
- Support API UpdateBackupPolicy.
- Support API UpdateInnerIpWhitelistGroup.
- Support API UpdateNodeGroupDescription.
- Support API UpdatePublicNetworkStatus.


2026-03-18 Version: 1.5.0
- Support API AddBackupPolicy.
- Support API CheckInventory.
- Support API CreateAgentResource.
- Support API CreateScalingRule.
- Support API DeleteBackup.
- Support API DeleteBackupPolicy.
- Support API DeleteInnerIpWhitelistGroup.
- Support API DeleteScalingRule.
- Support API DescribeAvailableZones.
- Support API DescribeBackupPolicies.
- Support API DescribeBackups.
- Support API DescribeEventNames.
- Support API DescribeInnerIpWhitelistGroups.
- Support API DescribeInstanceDiagnosisResult.
- Support API DescribeInstanceMetaToken.
- Support API DescribeRegions.
- Support API DescribeResourceConstraints.
- Support API DescribeSystemTimezone.
- Support API DescribeTimeTriggerScalingRules.
- Support API EnableInternalSlb.
- Support API EnableMultiAz.
- Support API GetNodeGroupFeatureGate.
- Support API ListOperationActivity.
- Support API ListOperationHistory.
- Support API ModifyHostAlias.
- Support API ModifyMaintainableTime.
- Support API ModifyScalingRule.
- Support API ModifySpecType.
- Support API ModifySpecTypePreCheck.
- Support API ModifyUserPassword.
- Support API QueryEnableMultiAzPrice.
- Support API QueryMinorVersion.
- Support API QueryModifyChargeTypePrice.
- Support API QueryModifyCuPrice.
- Support API QueryModifyDiskNumberPrice.
- Support API QueryModifyDiskPerformanceLevelPrice.
- Support API QueryModifyDiskSizePrice.
- Support API QueryModifyDiskTypePrice.
- Support API QueryModifyNodeNumberPrice.
- Support API QueryModifySpecTypePrice.
- Support API QueryPriceV1.
- Support API QueryRefundPrice.
- Support API QueryRenewPrice.
- Support API QueryUnpaidOrder.
- Support API RebootECS.
- Support API RenewInstance.
- Support API SwitchActiveStandbyZones.
- Support API ToggleAutoMinorVersionUpgrade.
- Support API UpdateBackup.
- Support API UpdateBackupPolicy.
- Support API UpdateInnerIpWhitelistGroup.
- Support API UpdateNodeGroupDescription.
- Support API UpdatePublicNetworkStatus.


2026-03-12 Version: 1.4.0
- Support API DescribeConfigHistory.
- Support API DescribeInstanceConfigs.
- Support API ModifyInstanceConfig.
- Support API ModifyInstanceConfigPreCheck.
- Support API RollbackConfigModification.


2026-02-27 Version: 1.3.2
- Update API DescribeNodeGroups: add request parameters body.tags.


2026-02-26 Version: 1.3.1
- Update API GetInstanceFeatureGate: add response parameters Body.Data.supportCompactionService.


2026-02-25 Version: 1.3.0
- Support API AddGateway.
- Support API DeleteGateway.
- Support API DisableSSLConnection.
- Support API EnableSSLConnection.
- Support API GetInstanceFeatureGate.
- Support API IsolateLeader.
- Support API ListGateway.
- Support API ModifyChargeType.
- Support API ModifyDiskType.
- Support API RestartNodeGroup.
- Support API RestartNodes.
- Support API RestoreInstance.
- Support API ResumeInstance.
- Support API TogglePublicSlb.
- Support API UpdateGateway.


2026-02-25 Version: 1.3.0
- Support API AddGateway.
- Support API DeleteGateway.
- Support API DisableSSLConnection.
- Support API EnableSSLConnection.
- Support API GetInstanceFeatureGate.
- Support API IsolateLeader.
- Support API ListGateway.
- Support API ModifyChargeType.
- Support API ModifyDiskType.
- Support API RestartNodeGroup.
- Support API RestartNodes.
- Support API RestoreInstance.
- Support API ResumeInstance.
- Support API TogglePublicSlb.
- Support API UpdateGateway.


2025-12-05 Version: 1.2.2
- Update API CreateInstanceV1: add request parameters body.DlfCatalogName.
- Update API CreateInstanceV1: add request parameters body.DlfCatalogType.
- Update API CreateInstanceV1: add request parameters body.LinkedRamUserName.
- Update API CreateInstanceV1: add request parameters body.PrincipalType.
- Update API CreateInstanceV1: add request parameters body.RamUserId.
- Update API DescribeNodeGroups: add response parameters Body.Data.$.Tags.


2025-11-25 Version: 1.2.1
- Update API ModifyNodeNumber: add request parameters Parallelism.
- Update API ModifyNodeNumber: add request parameters TerminationGracePeriodSeconds.


2025-10-22 Version: 1.2.0
- Support API DescribeNodeGroups.


2025-09-12 Version: 1.1.1
- Update API CreateInstanceV1: add request parameters body.AgentNodeGroup.
- Update API CreateInstanceV1: add request parameters body.AutoPay.
- Update API CreateInstanceV1: add request parameters body.GatewayType.
- Update API ModifyDiskSize: add request parameters FastMode.


2025-07-30 Version: 1.1.0
- Support API ChangeResourceGroup.
- Support API CreateInstanceV1.
- Support API CreateServiceLinkedRole.
- Support API DescribeInstances.
- Support API TagResources.
- Support API UnTagResources.


2025-07-02 Version: 1.0.1
- Generated python 2022-10-19 for starrocks.

2025-06-30 Version: 1.0.0
- Update API ModifyCu: add request parameters PromotionOptionNo.
- Update API ModifyDiskNumber: add request parameters PromotionOptionNo.
- Update API ModifyDiskPerformanceLevel: add request parameters PromotionOptionNo.
- Update API ModifyDiskSize: add request parameters PromotionOptionNo.
- Update API ModifyNodeNumber: add request parameters PromotionOptionNo.


